#ifndef BPF_FEATURES_H_
#define BPF_FEATURES_H_

/*** Misc kernel config items ***/
#define CONFIG_HZ 1000

/*** System call availability ***/
#define HAVE_BPF_SYSCALL

/*** eBPF program types ***/
#define HAVE_SOCKET_FILTER_PROG_TYPE
#define HAVE_KPROBE_PROG_TYPE
#define HAVE_SCHED_CLS_PROG_TYPE
#define HAVE_SCHED_ACT_PROG_TYPE
#define HAVE_TRACEPOINT_PROG_TYPE
#define HAVE_XDP_PROG_TYPE
#define HAVE_PERF_EVENT_PROG_TYPE
#define HAVE_CGROUP_SKB_PROG_TYPE
#define HAVE_CGROUP_SOCK_PROG_TYPE
#define HAVE_LWT_IN_PROG_TYPE
#define HAVE_LWT_OUT_PROG_TYPE
#define HAVE_LWT_XMIT_PROG_TYPE
#define HAVE_SOCK_OPS_PROG_TYPE
#define HAVE_SK_SKB_PROG_TYPE
#define HAVE_CGROUP_DEVICE_PROG_TYPE
#define HAVE_SK_MSG_PROG_TYPE
#define HAVE_RAW_TRACEPOINT_PROG_TYPE
#define HAVE_CGROUP_SOCK_ADDR_PROG_TYPE
#define HAVE_LWT_SEG6LOCAL_PROG_TYPE
#define NO_HAVE_LIRC_MODE2_PROG_TYPE
#define HAVE_SK_REUSEPORT_PROG_TYPE
#define HAVE_FLOW_DISSECTOR_PROG_TYPE
#define HAVE_CGROUP_SYSCTL_PROG_TYPE
#define HAVE_RAW_TRACEPOINT_WRITABLE_PROG_TYPE
#define HAVE_CGROUP_SOCKOPT_PROG_TYPE
#define NO_HAVE_TRACING_PROG_TYPE
#define NO_HAVE_STRUCT_OPS_PROG_TYPE
#define NO_HAVE_EXT_PROG_TYPE
#define NO_HAVE_LSM_PROG_TYPE
#define NO_HAVE_SK_LOOKUP_PROG_TYPE
#define NO_HAVE_SYSCALL_PROG_TYPE

/*** eBPF map types ***/
#define HAVE_HASH_MAP_TYPE
#define HAVE_ARRAY_MAP_TYPE
#define HAVE_PROG_ARRAY_MAP_TYPE
#define HAVE_PERF_EVENT_ARRAY_MAP_TYPE
#define HAVE_PERCPU_HASH_MAP_TYPE
#define HAVE_PERCPU_ARRAY_MAP_TYPE
#define HAVE_STACK_TRACE_MAP_TYPE
#define HAVE_CGROUP_ARRAY_MAP_TYPE
#define HAVE_LRU_HASH_MAP_TYPE
#define HAVE_LRU_PERCPU_HASH_MAP_TYPE
#define HAVE_LPM_TRIE_MAP_TYPE
#define HAVE_ARRAY_OF_MAPS_MAP_TYPE
#define HAVE_HASH_OF_MAPS_MAP_TYPE
#define HAVE_DEVMAP_MAP_TYPE
#define HAVE_SOCKMAP_MAP_TYPE
#define HAVE_CPUMAP_MAP_TYPE
#define NO_HAVE_XSKMAP_MAP_TYPE
#define HAVE_SOCKHASH_MAP_TYPE
#define HAVE_CGROUP_STORAGE_MAP_TYPE
#define HAVE_REUSEPORT_SOCKARRAY_MAP_TYPE
#define HAVE_PERCPU_CGROUP_STORAGE_MAP_TYPE
#define HAVE_QUEUE_MAP_TYPE
#define HAVE_STACK_MAP_TYPE
#define HAVE_SK_STORAGE_MAP_TYPE
#define HAVE_DEVMAP_HASH_MAP_TYPE
#define NO_HAVE_STRUCT_OPS_MAP_TYPE
#define NO_HAVE_RINGBUF_MAP_TYPE
#define NO_HAVE_INODE_STORAGE_MAP_TYPE
#define NO_HAVE_TASK_STORAGE_MAP_TYPE
#define NO_HAVE_BLOOM_FILTER_MAP_TYPE

/*** eBPF helper functions ***/
/*
 * Use HAVE_PROG_TYPE_HELPER(prog_type_name, helper_name)
 * to determine if <helper_name> is available for <prog_type_name>,
 * e.g.
 *	#if HAVE_PROG_TYPE_HELPER(xdp, bpf_redirect)
 *		// do stuff with this helper
 *	#elif
 *		// use a workaround
 *	#endif
 */
#define HAVE_PROG_TYPE_HELPER(prog_type, helper)	\
	BPF__PROG_TYPE_ ## prog_type ## __HELPER_ ## helper
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_load_bytes 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_socket_cookie 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_socket_uid 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_load_bytes_relative 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_socket_filter__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_probe_read 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_current_pid_tgid 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_current_uid_gid 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_current_comm 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_perf_event_read 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_stackid 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_current_task 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_current_task_under_cgroup 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_probe_read_str 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_perf_event_read_value 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_stack 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_current_cgroup_id 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_send_signal 1
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_kprobe__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_store_bytes 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_l3_csum_replace 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_l4_csum_replace 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_clone_redirect 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_cgroup_classid 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_vlan_push 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_vlan_pop 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_get_tunnel_key 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_set_tunnel_key 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_redirect 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_route_realm 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_load_bytes 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_csum_diff 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_get_tunnel_opt 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_set_tunnel_opt 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_change_proto 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_change_type 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_under_cgroup 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_hash_recalc 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_change_tail 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_pull_data 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_csum_update 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_set_hash_invalid 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_socket_cookie 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_socket_uid 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_set_hash 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_adjust_room 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_get_xfrm_state 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_load_bytes_relative 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_fib_lookup 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_cgroup_id 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_ancestor_cgroup_id 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sk_lookup_tcp 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sk_lookup_udp 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sk_release 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sk_fullsock 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_tcp_sock 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_ecn_set_ce 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_listener_sock 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skc_lookup_tcp 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_tcp_check_syncookie 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sk_storage_get 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sk_storage_delete 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_tcp_gen_syncookie 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sk_assign 1
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_sched_cls__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_store_bytes 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_l3_csum_replace 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_l4_csum_replace 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_clone_redirect 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_cgroup_classid 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_vlan_push 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_vlan_pop 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_get_tunnel_key 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_set_tunnel_key 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_redirect 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_route_realm 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_load_bytes 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_csum_diff 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_get_tunnel_opt 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_set_tunnel_opt 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_change_proto 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_change_type 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_under_cgroup 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_hash_recalc 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_change_tail 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_pull_data 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_csum_update 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_set_hash_invalid 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_socket_cookie 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_socket_uid 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_set_hash 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_adjust_room 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_get_xfrm_state 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_load_bytes_relative 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_fib_lookup 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_cgroup_id 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_ancestor_cgroup_id 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sk_lookup_tcp 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sk_lookup_udp 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sk_release 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sk_fullsock 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_tcp_sock 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_ecn_set_ce 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_listener_sock 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skc_lookup_tcp 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_tcp_check_syncookie 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sk_storage_get 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sk_storage_delete 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_tcp_gen_syncookie 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sk_assign 1
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_sched_act__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_probe_read 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_current_pid_tgid 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_current_uid_gid 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_current_comm 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_perf_event_read 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_stackid 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_current_task 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_current_task_under_cgroup 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_probe_read_str 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_stack 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_current_cgroup_id 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_send_signal 1
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_tracepoint__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_redirect 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_csum_diff 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_xdp_adjust_head 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_redirect_map 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_xdp_adjust_meta 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_xdp_adjust_tail 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_fib_lookup 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sk_lookup_tcp 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sk_lookup_udp 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sk_release 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skc_lookup_tcp 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_tcp_check_syncookie 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_tcp_gen_syncookie 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_xdp__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_xdp__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_probe_read 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_current_pid_tgid 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_current_uid_gid 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_current_comm 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_perf_event_read 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_stackid 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_current_task 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_current_task_under_cgroup 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_probe_read_str 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_perf_prog_read_value 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_stack 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_current_cgroup_id 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_send_signal 1
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_perf_event__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_load_bytes 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_socket_cookie 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_socket_uid 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_load_bytes_relative 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_cgroup_id 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_local_storage 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sk_fullsock 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_tcp_sock 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_ecn_set_ce 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_listener_sock 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sk_storage_get 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sk_storage_delete 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_cgroup_skb__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_current_pid_tgid 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_current_uid_gid 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_current_comm 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_cgroup_classid 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_socket_cookie 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_local_storage 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_netns_cookie 1
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_cgroup_sock__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_cgroup_classid 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_route_realm 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_load_bytes 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_csum_diff 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_under_cgroup 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_hash_recalc 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_pull_data 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_lwt_push_encap 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_lwt_in__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_cgroup_classid 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_route_realm 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_load_bytes 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_csum_diff 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_under_cgroup 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_hash_recalc 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_pull_data 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_lwt_out__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_store_bytes 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_l3_csum_replace 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_l4_csum_replace 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_clone_redirect 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_cgroup_classid 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_get_tunnel_key 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_set_tunnel_key 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_redirect 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_route_realm 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_load_bytes 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_csum_diff 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_get_tunnel_opt 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_set_tunnel_opt 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_under_cgroup 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_hash_recalc 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_change_tail 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_pull_data 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_csum_update 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_set_hash_invalid 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_change_head 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_lwt_push_encap 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_lwt_xmit__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_socket_cookie 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_setsockopt 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sock_map_update 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_getsockopt 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sock_ops_cb_flags_set 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sock_hash_update 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_local_storage 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_tcp_sock 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sk_storage_get 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sk_storage_delete 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_sock_ops__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_store_bytes 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_load_bytes 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_change_tail 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_pull_data 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_change_head 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_socket_cookie 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_socket_uid 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sk_redirect_map 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sk_redirect_hash 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sk_lookup_tcp 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sk_lookup_udp 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sk_release 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skc_lookup_tcp 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_sk_skb__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_ktime_get_ns 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_prandom_u32 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_smp_processor_id 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_tail_call 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_current_uid_gid 1
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_perf_event_output 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_numa_node_id 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_current_cgroup_id 1
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_local_storage 1
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_cgroup_device__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_current_pid_tgid 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_current_uid_gid 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_cgroup_classid 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_msg_redirect_map 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_msg_apply_bytes 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_msg_cork_bytes 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_msg_pull_data 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_msg_redirect_hash 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_msg_push_data 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_msg_pop_data 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_sk_msg__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_probe_read 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_current_pid_tgid 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_current_uid_gid 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_current_comm 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_perf_event_read 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_stackid 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_current_task 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_current_task_under_cgroup 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_probe_read_str 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_stack 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_current_cgroup_id 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_send_signal 1
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_raw_tracepoint__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_current_pid_tgid 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_current_uid_gid 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_current_comm 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_cgroup_classid 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_socket_cookie 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_bind 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_local_storage 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sk_lookup_tcp 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sk_lookup_udp 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sk_release 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skc_lookup_tcp 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sk_storage_get 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sk_storage_delete 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_netns_cookie 1
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_cgroup_sock_addr__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_cgroup_classid 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_route_realm 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_load_bytes 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_csum_diff 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_under_cgroup 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_hash_recalc 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_pull_data 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_lwt_seg6local__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_map_lookup_elem 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_map_update_elem 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_map_delete_elem 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_ktime_get_ns 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_prandom_u32 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_smp_processor_id 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_tail_call 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_perf_event_output 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_numa_node_id 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_map_push_elem 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_map_pop_elem 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_map_peek_elem 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_lirc_mode2__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_perf_event_output 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_load_bytes 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_load_bytes_relative 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sk_select_reuseport 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_sk_reuseport__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_perf_event_output 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_load_bytes 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_spin_lock 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_spin_unlock 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_jiffies64 1
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_flow_dissector__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_ktime_get_ns 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_prandom_u32 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_smp_processor_id 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_tail_call 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_current_uid_gid 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_perf_event_output 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_numa_node_id 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_current_cgroup_id 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_local_storage 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sysctl_get_name 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sysctl_get_current_value 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sysctl_get_new_value 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sysctl_set_new_value 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_strtol 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_strtoul 1
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_cgroup_sysctl__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_probe_read 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_ktime_get_ns 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_prandom_u32 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_smp_processor_id 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_tail_call 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_current_pid_tgid 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_current_uid_gid 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_current_comm 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_perf_event_read 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_perf_event_output 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_stackid 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_current_task 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_current_task_under_cgroup 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_numa_node_id 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_probe_read_str 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_stack 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_current_cgroup_id 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_send_signal 1
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_raw_tracepoint_writable__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_map_lookup_elem 1
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_map_update_elem 1
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_map_delete_elem 1
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_ktime_get_ns 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_prandom_u32 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_smp_processor_id 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_tail_call 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_current_uid_gid 1
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_perf_event_output 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_numa_node_id 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_current_cgroup_id 1
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_local_storage 1
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_map_push_elem 1
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_map_pop_elem 1
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_map_peek_elem 1
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_tcp_sock 1
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sk_storage_get 1
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sk_storage_delete 1
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_cgroup_sockopt__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_map_lookup_elem 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_map_update_elem 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_map_delete_elem 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_ktime_get_ns 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_prandom_u32 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_smp_processor_id 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_tail_call 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_perf_event_output 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_numa_node_id 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_map_push_elem 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_map_pop_elem 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_map_peek_elem 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_tracing__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_map_lookup_elem 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_map_update_elem 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_map_delete_elem 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_ktime_get_ns 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_prandom_u32 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_smp_processor_id 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_tail_call 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_perf_event_output 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_numa_node_id 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_map_push_elem 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_map_pop_elem 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_map_peek_elem 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_struct_ops__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_map_lookup_elem 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_map_update_elem 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_map_delete_elem 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_ktime_get_ns 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_prandom_u32 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_smp_processor_id 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_tail_call 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_perf_event_output 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_numa_node_id 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_map_push_elem 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_map_pop_elem 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_map_peek_elem 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_ext__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_map_lookup_elem 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_map_update_elem 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_map_delete_elem 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_ktime_get_ns 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_prandom_u32 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_smp_processor_id 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_tail_call 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_perf_event_output 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_numa_node_id 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_map_push_elem 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_map_pop_elem 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_map_peek_elem 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_lsm__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_map_lookup_elem 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_map_update_elem 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_map_delete_elem 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_ktime_get_ns 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_prandom_u32 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_smp_processor_id 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_tail_call 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_perf_event_output 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_numa_node_id 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_map_push_elem 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_map_pop_elem 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_map_peek_elem 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_sk_lookup__HELPER_bpf_ima_file_hash 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_map_lookup_elem 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_map_update_elem 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_map_delete_elem 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_probe_read 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_ktime_get_ns 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_prandom_u32 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_smp_processor_id 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_store_bytes 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_l3_csum_replace 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_l4_csum_replace 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_tail_call 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_clone_redirect 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_current_pid_tgid 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_current_uid_gid 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_current_comm 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_cgroup_classid 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_vlan_push 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_vlan_pop 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_get_tunnel_key 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_set_tunnel_key 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_perf_event_read 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_redirect 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_route_realm 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_perf_event_output 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_load_bytes 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_stackid 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_csum_diff 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_get_tunnel_opt 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_set_tunnel_opt 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_change_proto 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_change_type 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_under_cgroup 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_hash_recalc 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_current_task 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_current_task_under_cgroup 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_change_tail 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_pull_data 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_csum_update 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_set_hash_invalid 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_numa_node_id 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_change_head 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_xdp_adjust_head 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_probe_read_str 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_socket_cookie 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_socket_uid 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_set_hash 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_setsockopt 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_adjust_room 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_redirect_map 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sk_redirect_map 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sock_map_update 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_xdp_adjust_meta 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_perf_event_read_value 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_perf_prog_read_value 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_getsockopt 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_override_return 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sock_ops_cb_flags_set 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_msg_redirect_map 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_msg_apply_bytes 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_msg_cork_bytes 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_msg_pull_data 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_bind 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_xdp_adjust_tail 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_get_xfrm_state 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_stack 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_load_bytes_relative 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_fib_lookup 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sock_hash_update 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_msg_redirect_hash 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sk_redirect_hash 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_lwt_push_encap 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_lwt_seg6_store_bytes 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_lwt_seg6_adjust_srh 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_lwt_seg6_action 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_rc_repeat 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_rc_keydown 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_cgroup_id 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_current_cgroup_id 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_local_storage 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sk_select_reuseport 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sk_lookup_tcp 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sk_lookup_udp 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sk_release 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_map_push_elem 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_map_pop_elem 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_map_peek_elem 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_msg_push_data 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_msg_pop_data 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_rc_pointer_rel 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_spin_lock 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_spin_unlock 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sk_fullsock 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_tcp_sock 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_ecn_set_ce 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_listener_sock 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skc_lookup_tcp 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_tcp_check_syncookie 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sysctl_get_name 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sysctl_get_current_value 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sysctl_get_new_value 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sysctl_set_new_value 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_strtol 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_strtoul 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sk_storage_get 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sk_storage_delete 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_send_signal 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_tcp_gen_syncookie 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_output 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_probe_read_user 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_probe_read_kernel 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_probe_read_user_str 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_probe_read_kernel_str 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_tcp_send_ack 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_send_signal_thread 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_jiffies64 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_read_branch_records 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_ns_current_pid_tgid 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_xdp_output 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_netns_cookie 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_current_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sk_assign 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_ktime_get_boot_ns 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_seq_printf 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_seq_write 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sk_cgroup_id 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sk_ancestor_cgroup_id 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_ringbuf_output 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_ringbuf_reserve 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_ringbuf_submit 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_ringbuf_discard 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_ringbuf_query 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_csum_level 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skc_to_tcp6_sock 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skc_to_tcp_sock 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skc_to_tcp_timewait_sock 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skc_to_tcp_request_sock 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skc_to_udp6_sock 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_task_stack 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_load_hdr_opt 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_store_hdr_opt 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_reserve_hdr_opt 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_inode_storage_get 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_inode_storage_delete 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_d_path 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_copy_from_user 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_snprintf_btf 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_seq_printf_btf 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_cgroup_classid 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_redirect_neigh 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_per_cpu_ptr 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_this_cpu_ptr 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_redirect_peer 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_task_storage_get 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_task_storage_delete 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_current_task_btf 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_bprm_opts_set 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_ktime_get_coarse_ns 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_ima_inode_hash 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sock_from_file 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_check_mtu 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_for_each_map_elem 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_snprintf 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sys_bpf 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_btf_find_by_name_kind 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_sys_close 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_timer_init 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_timer_set_callback 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_timer_start 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_timer_cancel 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_func_ip 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_attach_cookie 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_task_pt_regs 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_branch_snapshot 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skc_to_unix_sock 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_kallsyms_lookup_name 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_find_vma 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_loop 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_strncmp 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_func_arg 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_func_ret 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_func_arg_cnt 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_get_retval 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_set_retval 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_xdp_get_buff_len 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_xdp_load_bytes 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_xdp_store_bytes 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_copy_from_user_task 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_skb_set_tstamp 0
#define BPF__PROG_TYPE_syscall__HELPER_bpf_ima_file_hash 0

/*** eBPF misc features ***/
#define HAVE_LARGE_INSN_LIMIT
#define HAVE_BOUNDED_LOOPS
#define HAVE_V2_ISA_EXTENSION
#define HAVE_V3_ISA_EXTENSION

#endif /* BPF_FEATURES_H_ */
